abacusai.llm_app — AbacusAI documentation

# abacusai.llm_app

## Classes

`LlmApp` | An LLM App that can be used for generation. LLM Apps are specifically crafted to help with certain tasks like code generation or question answering.

## Module Contents

class abacusai.llm_app.LlmApp(client, llmAppId=None, name=None, description=None, projectId=None, deploymentId=None, createdAt=None, updatedAt=None, status=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An LLM App that can be used for generation. LLM Apps are specifically crafted to help with certain tasks like code generation or question answering.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - llmAppId (str) – The unique identifier of the LLM App.

    - name (str) – The name of the LLM App.

    - description (str) – The description of the LLM App.

    - projectId (str) – The project ID of the deployment associated with the LLM App.

    - deploymentId (str) – The deployment ID associated with the LLM App.

    - createdAt (str) – The timestamp at which the LLM App was created.

    - updatedAt (str) – The timestamp at which the LLM App was updated.

    - status (str) – The status of the LLM App’s deployment.

  llm_app_id = None
  name = None
  description = None
  project_id = None
  deployment_id = None
  created_at = None
  updated_at = None
  status = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict